from django.apps import AppConfig


class DjangoAiKitAuthConfig(AppConfig):
    name = "ai_kit_auth"
    verbose_name = "Ai Kit: Authentication"
